#!/bin/sh

# This script is call from udev rules for NI PCI Hardware to ensure that
# the associated NI driver is attached instead of any built-in kernel drivers

ADDRESS=$1
NI_DRIVER=$2

# Set the driver override so other drivers don't try to attach on subsequent boots
echo "$NI_DRIVER" > "/sys/bus/pci/devices/$ADDRESS/driver_override"

# Loop for 20 seconds in case there is a race condition on binding
loopCounter=0
while [ $loopCounter -ne 20 ]; do

   driverSymlink=$(readlink -f "/sys/bus/pci/devices/$ADDRESS/driver")

   case $driverSymlink in
      *"$NI_DRIVER"*)
         # We are bound to the NI Driver
         exit 0
      ;;
      *)
         # We are not bound to the NI Driver

         # Only attempt to unbind if the driver is already bound
         if [ -e "/sys/bus/pci/devices/$ADDRESS/driver" ]; then
            echo "$ADDRESS" > "/sys/bus/pci/devices/$ADDRESS/driver/unbind"
         fi

         # Bind to the NI driver
         echo "$ADDRESS" > "/sys/bus/pci/drivers/$NI_DRIVER/bind"
      ;;
   esac

   loopCounter=$((loopCounter+1))
   if [ $loopCounter -gt 1 ]; then
      sleep 1
   fi

done
